@@ -21,7 +21,7 @@ use List::Util qw(max);
 
 use Tickit::Widget::Tabbed::Ribbon;
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 =head1 NAME
 
@@ -588,7 +588,10 @@ sub set_on_deactivated
 
 =head2 pen
 
-Returns the C<Tickit::Pen> used to draw the label
+Returns the C<Tickit::Pen> used to draw the label.
+
+Pen observers are no longer registered on the return value; to set a different
+pen on the tab, use the C<set_pen> method instead.
 
 =cut
 
@@ -596,15 +599,12 @@ sub _has_pen { defined shift->{pen} }
 
 sub pen {
         my $self = shift;
-        return $self->{pen} ||= do {
-                my $pen = Tickit::Pen->new;
-                $pen->add_on_changed( $self );
-                $pen
-        };
+        return $self->{pen};
 }
 
-sub on_pen_changed {
+sub set_pen {
         my $self = shift;
+        ( $self->{pen} ) = @_;
         $self->{tabbed}->_tabs_changed if $self->{tabbed};
 }
 
